

def to_char(char_in):
    if(char_in == '๐'):
        return "0"
    if(char_in == '๑'):
        return "1"
    if(char_in == '๒'):
        return "2"
    if(char_in == '๓'):
        return "3"
    if(char_in == '๔'):
        return "4"
    if(char_in == '๕'):
        return "5"
    if(char_in == '๖'):
        return "6"
    if(char_in == '๗'):
        return "7"
    if(char_in == '๘'):
        return "8"
    if(char_in == '๙'):
        return "9"
    return char_in

def to_str(str_in):
    tmp_str = ""
    for tmp_ch in str_in:
       tmp_str = tmp_str + to_char(tmp_ch)
    return tmp_str


def to_int(str_in):
    try:
        tmp_eng = to_str(str_in)
        return int(tmp_eng)
    except:
        return 0
    






from setuptools import setup, find_packages


setup(
    name='py_thai_num',
    version='0.2.1',
    license='MIT',
    author="Worakrit Sittirit",
    author_email='kritsitti.coe@gmail.com',
    packages=find_packages('src'),
    package_dir={'': 'src'},
    url='https://github.com/worakrit-sittirit/py_thai_num.git',
    keywords='Thai number to eng',
    description= "python lib for conversion Thai numerical to global numerical.",

)



from py_thai_num import py_thai_num

def to_str(file_name):
    tmp_str = ""
    tmp_f = open(file_name, "r")
    while 1:
    
        # read by character
        tmp_ch = tmp_f.read(1)         
        if not tmp_ch:
            break
        tmp_str = tmp_str + py_thai_num.to_char(tmp_ch)
        
    tmp_f.close()

    return tmp_str

def to_file(file_in, file_out):
    
    tmp_f = open(file_in, "r")
    tmp_fo = open(file_out, "w")
    while 1:
    
        # read by character
        tmp_ch = tmp_f.read(1)         
        if not tmp_ch:
            break
        tmp_ch = py_thai_num.to_char(tmp_ch)
        tmp_fo.write(tmp_ch)
    
    tmp_f.close()
    tmp_fo.close()

    return 0;


